Audio class

See play method as well as example app on how to use.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → Future<void>
play(String url, {String title = "", String subtitle = "", Duration position = Duration.zero, bool isLiveStream = false}) → Future<void>
Plays given url with native player. The title and subtitle are used for lock screen info panel on both iOS & Android. Optionally pass in current position to start playback from that point. The isLiveStream flag is only used on iOS to change the scrub-bar look on lock screen info panel. It has no affect on the actual functionality of the plugin. Defaults to false.
reset() → Future<void>
seekTo(double seconds) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

instance() → Audio?