TextTrack class

Used for adding text tracks to the player. mimetype is the type of text track for example text/webvtt. languageCode is the language of the track for example en or fr and uri is the location for the track.

Constructors

TextTrack(String mimetype, String languageCode, String uri)
TextTrack.from({required String mimetype, required String languageCode, required String uri})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode → String
final
mimetype → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

toJsonFromList(List<TextTrack> tracks) → List